package xcom.thoughtworks.xstream.io.xml;


import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.junit.Test;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import xcom.thoughtworks.xstream.io.HierarchicalStreamReader;
import xcom.thoughtworks.xstream.io.xml.DomReader;
import xcom.thoughtworks.xstream.io.xml.XmlFriendlyNameCoder;

public class XMLFNCCumulativeTS_junit {

	@Test
	public void test_12() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("A^-Node");

		assertEquals("A_Node", ncoder.decodeNode("A^-Node"));

	}

	@Test
	public void test_1_12() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("A^Node");

		assertEquals("A^Node", ncoder.decodeNode("A^Node"));

	}

	@Test
	public void test_22() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("_-Node");

		assertEquals("$Node", ncoder.decodeNode("_-Node"));

	}

	@Test
	public void test_2_22() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("_Node");

		assertEquals("_Node", ncoder.decodeNode("_Node"));

	}

	@Test
	public void test_32() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("ANode");

		assertEquals("ANode", ncoder.decodeNode("ANode"));

	}

	@Test
	public void test_13() {

		String dollarReplacement = "!-_";
		String escapeCharReplacement = "_!-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Node!-_");

		assertEquals("Node$", ncoder.decodeNode("Node!-_"));

	}

	@Test
	public void test_1_13() {

		String dollarReplacement = "!-_";
		String escapeCharReplacement = "_!-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Node!");

		assertEquals("Node!", ncoder.decodeNode("Node!"));

	}

	@Test
	public void test_23() {

		String dollarReplacement = "!-_";
		String escapeCharReplacement = "_!_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("_!_Node");

		assertEquals("_Node", ncoder.decodeNode("_!_Node"));

	}

	@Test
	public void test_2_23() {

		String dollarReplacement = "---";
		String escapeCharReplacement = "!--";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another!");

		assertEquals("Another!", ncoder.decodeNode("Another!"));

	}

	@Test
	public void test_33() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("ANode");

		assertEquals("ANode", ncoder.decodeNode("ANode"));

	}

	@Test
	public void test_14() {

		String dollarReplacement = "^^";
		String escapeCharReplacement = "_!-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("^^Node");

		assertEquals("$Node", ncoder.decodeNode("^^Node"));

	}

	@Test
	public void test_1_14() {

		String dollarReplacement = "^^";
		String escapeCharReplacement = "_!-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("^N^ode");

		assertEquals("^N^ode", ncoder.decodeNode("^N^ode"));

	}

	@Test
	public void test_24() {

		String dollarReplacement = "!-_";
		String escapeCharReplacement = "!!";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("!!Node");

		assertEquals("_Node", ncoder.decodeNode("!!Node"));

	}

	@Test
	public void test_2_24() {

		String dollarReplacement = "-_";
		String escapeCharReplacement = "!!";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("a!Node");

		assertEquals("a!Node", ncoder.decodeNode("a!Node"));

	}

	@Test
	public void test_34() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("ANode");

		assertEquals("ANode", ncoder.decodeNode("ANode"));

	}

	@Test
	public void test_15() {

		String dollarReplacement = "!-";
		String escapeCharReplacement = "_!";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Yanother!-Node");

		assertEquals("Yanother$Node", ncoder.decodeNode("Yanother!-Node"));

	}

	@Test
	public void test_1_15() {

		String dollarReplacement = "!-";
		String escapeCharReplacement = "_-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another!Node");

		assertEquals("Another!Node", ncoder.decodeNode("Another!Node"));

	}

	@Test
	public void test_25() {

		String dollarReplacement = "!-";
		String escapeCharReplacement = "_!";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("_!Node");

		assertEquals("_Node", ncoder.decodeNode("_!Node"));

	}

	@Test
	public void test_2_25() {

		String dollarReplacement = "--";
		String escapeCharReplacement = "!-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another!Node");

		assertEquals("Another!Node", ncoder.decodeNode("Another!Node"));

	}

	@Test
	public void test_35() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("ANode");

		assertEquals("ANode", ncoder.decodeNode("ANode"));

	}

	@Test
	public void test_1() {

		String dollarReplacement = "--";
		String escapeCharReplacement = "_-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("--Node");

		assertEquals("$Node", ncoder.decodeNode("--Node"));

	}

	@Test
	public void test_1_1() {

		String dollarReplacement = "--";
		String escapeCharReplacement = "_-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another-Node");

		assertEquals("Another-Node", ncoder.decodeNode("Another-Node"));

	}

	@Test
	public void test_2() {

		String dollarReplacement = "--";
		String escapeCharReplacement = "_-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another_-Node");

		assertEquals("Another_Node", ncoder.decodeNode("Another_-Node"));

	}

	@Test
	public void test_2_2() {
		String dollarReplacement = "--";
		String escapeCharReplacement = "_-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("Another_Node");

		assertEquals("Another_Node", ncoder.decodeNode("Another_Node"));

	}

	@Test
	public void test_3() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		ncoder.decodeNode("ANode");

		assertEquals("ANode", ncoder.decodeNode("ANode"));

	}

	@Test
	public void test_122() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		assertTrue(nameCoder.decodeNode("test").equals("test"));
	}

	@Test
	public void test_222() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder("_-", "*_");
		assertTrue(nameCoder.decodeNode("t*_est").equals("t_est"));
	}

	@Test
	public void test_322() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder("_-", "*_");
		assertTrue(nameCoder.decodeNode("_-te*_st").equals("$te_st"));
	}

	@Test
	public void test_4() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		assertTrue(nameCoder.decodeNode("_test").equals("_test"));
	}

	@Test
	public void test_5() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		nameCoder.decodeNode("t__est");
		assertTrue(nameCoder.decodeNode("t__est").equals("t_est"));
	}

	/**
	 * @Test public void test_6() { XmlFriendlyNameCoder nameCoder = new
	 *       XmlFriendlyNameCoder(); char data[] = new char[1024 * 1024]; for
	 *       (int i = 1; i < data.length; i++) { data[i] = 'a'; } String d =
	 *       String.valueOf(data); long nanoTime = System.nanoTime();
	 *       assertTrue(nameCoder.decodeNode(d).equals(d)); long simple =
	 *       System.nanoTime() - nanoTime;
	 * 
	 *       data[0] = '_'; d = String.valueOf(data); nanoTime =
	 *       System.nanoTime(); assertTrue(nameCoder.decodeNode(d).equals(d));
	 *       long complex = System.nanoTime() - nanoTime;
	 * 
	 *       assertTrue(complex > simple * 1.6);
	 * 
	 *       nanoTime = System.nanoTime();
	 *       assertTrue(nameCoder.decodeNode(d).equals(d)); long complex2 =
	 *       System.nanoTime() - nanoTime;
	 * 
	 *       assertTrue(complex > complex2 * 3); }
	 */
	@Test
	public void testCorrectWriting_1() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		String result1 = "I$Node";

		assertEquals(xmlReader.getNodeName() + xmlReader.getNodeName(), result1 + result1);
		// kept the double variables to keep it the same as the original test.
	}

	@Test
	public void testErrorWriting_1() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("I_a-Node", xmlReader.getNodeName());
	}

	@Test
	public void testCorrectWriting_2() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I__Node hello='world' a='b' c='d'><empty/></I__Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("I_Node", xmlReader.getNodeName());
	}

	// @Test
	// public void testErrorWriting_2() throws ParserConfigurationException,
	// SAXException, IOException {
	// String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
	// DocumentBuilderFactory documentBuilderFactory =
	// DocumentBuilderFactory.newInstance();
	// DocumentBuilder documentBuilder =
	// documentBuilderFactory.newDocumentBuilder();
	// ByteArrayInputStream inputStream = new
	// ByteArrayInputStream(xml.getBytes());
	// Document document = documentBuilder.parse(inputStream);
	//
	// HierarchicalStreamReader xmlReader = new DomReader(document);
	//
	// assertEquals("I_a-Node", xmlReader.getNodeName());
	// }
	//
	// @Test
	// public void testCorrectWriting_3() throws ParserConfigurationException,
	// SAXException, IOException {
	// String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
	// DocumentBuilderFactory documentBuilderFactory =
	// DocumentBuilderFactory.newInstance();
	// DocumentBuilder documentBuilder =
	// documentBuilderFactory.newDocumentBuilder();
	// ByteArrayInputStream inputStream = new
	// ByteArrayInputStream(xml.getBytes());
	// Document document = documentBuilder.parse(inputStream);
	//
	// HierarchicalStreamReader xmlReader = new DomReader(document);
	//
	// assertEquals("I$Node", xmlReader.getNodeName());
	// }

	@Test
	public void testCorrectWriting_4() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<aI_-Node hello='world' a='b' c='d'><empty/></aI_-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("aI$Node", xmlReader.getNodeName());
	}

	@Test
	public void testCorrectWriting_5() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<IaNode hello='world' a='b' c='d'><empty/></IaNode>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("IaNode", xmlReader.getNodeName());
	}

	@Test
	public void testNew_Killing_Tcs_1() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("IZ_Node", ncoder.decodeNode("IZ^-Node"));
	}

	@Test
	public void testNew_Killing_Tcs_2() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("$node", ncoder.decodeNode("_-node"));
	}

	@Test
	public void testNew_Killing_Tcs_3() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";
		String name = "_-nodenodenode";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("$nodenodenode", ncoder.decodeNode(name));
	}

	@Test
	public void testNew_Killing_Tcs_4() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";
		String name = "^-nodenodenode";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("_nodenodenode", ncoder.decodeNode(name));
	}

	@Test
	public void test_emptyString() {
		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder();
		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_escapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("A^-Node");

		String expected = "A_Node";

		assertTrue(decoded.equals(expected));

		// for if(s != null) coverage
		decoded = ncoder.decodeNode("A^-Node");
		assertTrue(decoded.equals(expected));
	}

	// @Test
	// public void testDecodeNode_noReplacements() {
	//
	// String dollarReplacement = "_-";
	// String escapeCharReplacement = "^_";
	//
	// XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
	// dollarReplacement, escapeCharReplacement);
	//
	// String decoded = ncoder.decodeNode("Yo");
	// String expected = "Yo";
	//
	// assertTrue(decoded.equals(expected));
	// }

	@Test
	public void testDecodeNode_partialDollarChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_a");

		String expected = "_a";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_partialEscapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^a");
		String expected = "^a";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_emptyString() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithDollarReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_-Hello^_There!");
		String expected = "$Hello_There!";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithEscapeCharReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^_HowAreYou");
		String expected = "_HowAreYou";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_escapeChar1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("A^-Node");

		String expected = "A_Node";

		assertTrue(decoded.equals(expected));

		// for if(s != null) coverage
		decoded = ncoder.decodeNode("A^-Node");
		assertTrue(decoded.equals(expected));
	}

	// @Test
	// public void testDecodeNode_noReplacements() {
	//
	// String dollarReplacement = "_-";
	// String escapeCharReplacement = "^_";
	//
	// XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
	// dollarReplacement, escapeCharReplacement);
	//
	// String decoded = ncoder.decodeNode("Yo");
	// String expected = "Yo";
	//
	// assertTrue(decoded.equals(expected));
	// }

	@Test
	public void testDecodeNode_emptyString1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithDollarReplacement1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_-Hello^_There!");
		String expected = "$Hello_There!";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithEscapeCharReplacement1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^_HowAreYou");
		String expected = "_HowAreYou";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_partialDollarChar1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_a");

		String expected = "_a";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_partialEscapeChar1() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^a");
		String expected = "^a";

		assertTrue(decoded.equals(expected));
	}
}
