package xcom.thoughtworks.xstream.io.xml;

import static org.junit.Assert.assertTrue;
import org.junit.Test;

public class XMLFNCMutationAdeqTs_PIT_allMutops {
	
	@Test
	public void testDecodeNode_escapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("A^-Node");

		String expected = "A_Node";

		assertTrue(decoded.equals(expected));

		// for if(s != null) coverage
		decoded = ncoder.decodeNode("A^-Node");
		assertTrue(decoded.equals(expected));
	}

//	@Test
//	public void testDecodeNode_noReplacements() {
//
//		String dollarReplacement = "_-";
//		String escapeCharReplacement = "^_";
//
//		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
//				dollarReplacement, escapeCharReplacement);
//
//		String decoded = ncoder.decodeNode("Yo");
//		String expected = "Yo";
//
//		assertTrue(decoded.equals(expected));
//	}

	@Test
	public void testDecodeNode_partialDollarChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_a");

		String expected = "_a";

		assertTrue(decoded.equals(expected));
	}
	
	@Test
	public void testDecodeNode_partialEscapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^a");
		String expected = "^a";

		assertTrue(decoded.equals(expected));
	}
	
	@Test
	public void testDecodeNode_emptyString() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithDollarReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_-Hello^_There!");
		String expected = "$Hello_There!";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithEscapeCharReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
				dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^_HowAreYou");
		String expected = "_HowAreYou";

		assertTrue(decoded.equals(expected));
	}
	
}
