package xcom.thoughtworks.xstream.io.xml;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.junit.Test;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import xcom.thoughtworks.xstream.io.HierarchicalStreamReader;

public class XMLFNCMutationAdeqTs_mujava3_junit {

    @Test
    public void testCorrectWriting_1() throws ParserConfigurationException, SAXException, IOException {
        String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
        Document document = documentBuilder.parse(inputStream);

        HierarchicalStreamReader xmlReader = new DomReader(document);

        String result1 = "I$Node";

        assertEquals(xmlReader.getNodeName() + xmlReader.getNodeName(), result1 + result1);
        //kept the double variables to keep it the same as the original test.
    }

    @Test
    public void testErrorWriting_1() throws ParserConfigurationException, SAXException, IOException {
        String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
        Document document = documentBuilder.parse(inputStream);

        HierarchicalStreamReader xmlReader = new DomReader(document);

        assertEquals("I_a-Node", xmlReader.getNodeName());
    }

    @Test
    public void testCorrectWriting_2() throws ParserConfigurationException, SAXException, IOException {
        String xml = "<I__Node hello='world' a='b' c='d'><empty/></I__Node>";
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
        Document document = documentBuilder.parse(inputStream);

        HierarchicalStreamReader xmlReader = new DomReader(document);

        assertEquals("I_Node", xmlReader.getNodeName());
    }

//    @Test
//    public void testErrorWriting_2() throws ParserConfigurationException, SAXException, IOException {
//        String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
//        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
//        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
//        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
//        Document document = documentBuilder.parse(inputStream);
//
//        HierarchicalStreamReader xmlReader = new DomReader(document);
//
//        assertEquals("I_a-Node", xmlReader.getNodeName());
//    }
//
//    @Test
//    public void testCorrectWriting_3() throws ParserConfigurationException, SAXException, IOException {
//        String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
//        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
//        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
//        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
//        Document document = documentBuilder.parse(inputStream);
//
//        HierarchicalStreamReader xmlReader = new DomReader(document);
//
//        assertEquals("I$Node", xmlReader.getNodeName());
//    }

    @Test
    public void testCorrectWriting_4() throws ParserConfigurationException, SAXException, IOException {
        String xml = "<aI_-Node hello='world' a='b' c='d'><empty/></aI_-Node>";
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
        Document document = documentBuilder.parse(inputStream);

        HierarchicalStreamReader xmlReader = new DomReader(document);

        assertEquals("aI$Node", xmlReader.getNodeName());
    }

    @Test
    public void testCorrectWriting_5() throws ParserConfigurationException, SAXException, IOException {
        String xml = "<IaNode hello='world' a='b' c='d'><empty/></IaNode>";
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
        ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
        Document document = documentBuilder.parse(inputStream);

        HierarchicalStreamReader xmlReader = new DomReader(document);

        assertEquals("IaNode", xmlReader.getNodeName());
    }

    @Test
    public void testNew_Killing_Tcs_1() {
        String dollarReplacement = "_-";
        String escapeCharReplacement = "^-";

        XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

        assertEquals("IZ_Node", ncoder.decodeNode("IZ^-Node"));
    }

    @Test
    public void testNew_Killing_Tcs_2() {
        String dollarReplacement = "_-";
        String escapeCharReplacement = "^-";

        XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

        assertEquals("$node", ncoder.decodeNode("_-node"));
    }

    @Test
    public void testNew_Killing_Tcs_3() {
        String dollarReplacement = "_-";
        String escapeCharReplacement = "^-";
        String name = "_-nodenodenode";

        XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

        assertEquals("$nodenodenode", ncoder.decodeNode(name));
    }

    @Test
    public void testNew_Killing_Tcs_4() {
        String dollarReplacement = "_-";
        String escapeCharReplacement = "^-";
        String name = "^-nodenodenode";

        XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

        assertEquals("_nodenodenode", ncoder.decodeNode(name));
    }
    
    @Test
	public void test_emptyString() {
		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder();
		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

}
