package xcom.thoughtworks.xstream.io.xml;


import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.junit.Test;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import xcom.thoughtworks.xstream.io.HierarchicalStreamReader;
import xcom.thoughtworks.xstream.io.xml.DomReader;
import xcom.thoughtworks.xstream.io.xml.XmlFriendlyNameCoder;

public class decodeNameMutationAdeqTests_junitformat {

	@Test
	public void test_122() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		assertTrue(nameCoder.decodeNode("test").equals("test"));
	}

	@Test
	public void test_222() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder("_-", "*_");
		assertTrue(nameCoder.decodeNode("t*_est").equals("t_est"));
	}

	@Test
	public void test_322() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder("_-", "*_");
		assertTrue(nameCoder.decodeNode("_-te*_st").equals("$te_st"));
	}

	@Test
	public void test_4() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		assertTrue(nameCoder.decodeNode("_test").equals("_test"));
	}

	@Test
	public void test_5() {
		XmlFriendlyNameCoder nameCoder = new XmlFriendlyNameCoder();
		nameCoder.decodeNode("t__est");
		assertTrue(nameCoder.decodeNode("t__est").equals("t_est"));
	}

	/**
	 * @Test public void test_6() { XmlFriendlyNameCoder nameCoder = new
	 *       XmlFriendlyNameCoder(); char data[] = new char[1024 * 1024]; for
	 *       (int i = 1; i < data.length; i++) { data[i] = 'a'; } String d =
	 *       String.valueOf(data); long nanoTime = System.nanoTime();
	 *       assertTrue(nameCoder.decodeNode(d).equals(d)); long simple =
	 *       System.nanoTime() - nanoTime;
	 * 
	 *       data[0] = '_'; d = String.valueOf(data); nanoTime =
	 *       System.nanoTime(); assertTrue(nameCoder.decodeNode(d).equals(d));
	 *       long complex = System.nanoTime() - nanoTime;
	 * 
	 *       assertTrue(complex > simple * 1.6);
	 * 
	 *       nanoTime = System.nanoTime();
	 *       assertTrue(nameCoder.decodeNode(d).equals(d)); long complex2 =
	 *       System.nanoTime() - nanoTime;
	 * 
	 *       assertTrue(complex > complex2 * 3); }
	 */
	@Test
	public void testCorrectWriting_1() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		String result1 = "I$Node";

		assertEquals(xmlReader.getNodeName() + xmlReader.getNodeName(), result1 + result1);
		// kept the double variables to keep it the same as the original test.
	}

	@Test
	public void testErrorWriting_1() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("I_a-Node", xmlReader.getNodeName());
	}

	@Test
	public void testCorrectWriting_2() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<I__Node hello='world' a='b' c='d'><empty/></I__Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("I_Node", xmlReader.getNodeName());
	}

	// @Test
	// public void testErrorWriting_2() throws ParserConfigurationException,
	// SAXException, IOException {
	// String xml = "<I_a-Node hello='world' a='b' c='d'><empty/></I_a-Node>";
	// DocumentBuilderFactory documentBuilderFactory =
	// DocumentBuilderFactory.newInstance();
	// DocumentBuilder documentBuilder =
	// documentBuilderFactory.newDocumentBuilder();
	// ByteArrayInputStream inputStream = new
	// ByteArrayInputStream(xml.getBytes());
	// Document document = documentBuilder.parse(inputStream);
	//
	// HierarchicalStreamReader xmlReader = new DomReader(document);
	//
	// assertEquals("I_a-Node", xmlReader.getNodeName());
	// }
	//
	// @Test
	// public void testCorrectWriting_3() throws ParserConfigurationException,
	// SAXException, IOException {
	// String xml = "<I_-Node hello='world' a='b' c='d'><empty/></I_-Node>";
	// DocumentBuilderFactory documentBuilderFactory =
	// DocumentBuilderFactory.newInstance();
	// DocumentBuilder documentBuilder =
	// documentBuilderFactory.newDocumentBuilder();
	// ByteArrayInputStream inputStream = new
	// ByteArrayInputStream(xml.getBytes());
	// Document document = documentBuilder.parse(inputStream);
	//
	// HierarchicalStreamReader xmlReader = new DomReader(document);
	//
	// assertEquals("I$Node", xmlReader.getNodeName());
	// }

	@Test
	public void testCorrectWriting_4() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<aI_-Node hello='world' a='b' c='d'><empty/></aI_-Node>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("aI$Node", xmlReader.getNodeName());
	}

	@Test
	public void testCorrectWriting_5() throws ParserConfigurationException, SAXException, IOException {
		String xml = "<IaNode hello='world' a='b' c='d'><empty/></IaNode>";
		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
		ByteArrayInputStream inputStream = new ByteArrayInputStream(xml.getBytes());
		Document document = documentBuilder.parse(inputStream);

		HierarchicalStreamReader xmlReader = new DomReader(document);

		assertEquals("IaNode", xmlReader.getNodeName());
	}

	@Test
	public void testNew_Killing_Tcs_1() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("IZ_Node", ncoder.decodeNode("IZ^-Node"));
	}

	@Test
	public void testNew_Killing_Tcs_2() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("$node", ncoder.decodeNode("_-node"));
	}

	@Test
	public void testNew_Killing_Tcs_3() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";
		String name = "_-nodenodenode";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("$nodenodenode", ncoder.decodeNode(name));
	}

	@Test
	public void testNew_Killing_Tcs_4() {
		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";
		String name = "^-nodenodenode";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		assertEquals("_nodenodenode", ncoder.decodeNode(name));
	}

	@Test
	public void test_emptyString() {
		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder();
		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_escapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^-";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("A^-Node");

		String expected = "A_Node";

		assertTrue(decoded.equals(expected));

		// for if(s != null) coverage
		decoded = ncoder.decodeNode("A^-Node");
		assertTrue(decoded.equals(expected));
	}

	// @Test
	// public void testDecodeNode_noReplacements() {
	//
	// String dollarReplacement = "_-";
	// String escapeCharReplacement = "^_";
	//
	// XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(
	// dollarReplacement, escapeCharReplacement);
	//
	// String decoded = ncoder.decodeNode("Yo");
	// String expected = "Yo";
	//
	// assertTrue(decoded.equals(expected));
	// }

	@Test
	public void testDecodeNode_partialDollarChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_a");

		String expected = "_a";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_partialEscapeChar() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^a");
		String expected = "^a";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_emptyString() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("");
		String expected = "";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithDollarReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("_-Hello^_There!");
		String expected = "$Hello_There!";

		assertTrue(decoded.equals(expected));
	}

	@Test
	public void testDecodeNode_startsWithEscapeCharReplacement() {

		String dollarReplacement = "_-";
		String escapeCharReplacement = "^_";

		XmlFriendlyNameCoder ncoder = new XmlFriendlyNameCoder(dollarReplacement, escapeCharReplacement);

		String decoded = ncoder.decodeNode("^_HowAreYou");
		String expected = "_HowAreYou";

		assertTrue(decoded.equals(expected));
	}

}
